"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseApplication = void 0;
var Koa = require("koa");
var routing_controllers_1 = require("routing-controllers");
var typedi_1 = require("typedi");
var BaseApplication = /** @class */ (function () {
    function BaseApplication() {
        this._controllers = [];
        this._middlewares = [];
        routing_controllers_1.useContainer(typedi_1.Container);
        this._koa = new Koa();
    }
    BaseApplication.prototype.start = function (port) {
        routing_controllers_1.useKoaServer(this._koa, {
            validation: {
                validationError: {
                    target: false,
                },
            },
            defaultErrorHandler: false,
            cors: true,
            controllers: this._controllers,
            middlewares: this._middlewares,
        });
        this._server = this._koa.listen(port);
    };
    BaseApplication.prototype.stop = function () {
        this._server.close();
    };
    BaseApplication.prototype.useController = function (controller) {
        if (typeof controller === "function") {
            this._controllers.push(controller);
        }
        else {
            this._controllers.push(controller);
        }
    };
    BaseApplication.prototype.useMiddleware = function (middleware) {
        if (typeof middleware === "function") {
            this._middlewares.push(middleware);
        }
        else {
            this._middlewares.push(middleware);
        }
    };
    return BaseApplication;
}());
exports.BaseApplication = BaseApplication;
//# sourceMappingURL=BaseApplication.js.map